.section .rodata

msg:
	.asciz "booting..."
msgend:

msglen:
	.word (msgend - msg)

errmsg:
	.asciz "disk error!"
errmsgend:

errmsglen:
	.word (errmsgend - errmsg)

.section .text

.globl Start

Start:
	.code16

SaveDriveNumber:
	# Save Boot Device Number just before MBR load address
	# This byte is set by the BIOS into registry DL
	movb %dl, 0x7bff

SetVideoMode:
	clrb %ah			# Set Video Mode
	movb $0x03, %al			# 3rd Mode -> 80x25
	int $0x10			# Video Interrupt

PrintBootMsg:
	movb $0x06, %ah			# Clear Screen
	clrb %al			# Lines to scroll (0 = clear -> CX & DX)
	movb $0x0f, %bh			# Color Black White
	clrw %cx			# Upper Left Corner
	movb $25, %dh			# 25 Lines
	movb $80, %dl			# 80 Columns
	int $0x10			# Video Interrupt

	clrw %ax
	movw %ax, %es			# Set Extra Segment to 0x0
	movw $msg, %bp			# Set base pointer to msg location

	movb $0x13, %ah			# Print String
	movb $0x01, %al			# Char only - Cursor moved
	clrb %bh			# Page Number
	movb $0x0f, %bl			# Color Black White
	movw msglen, %cx		# Message Length
	movb $1, %dh			# Row 1 
	movb $1, %dl			# Column 1
	int $0x10			# Video Interrupt

ResetDisk:
	clrb %ah			# Reset Disk
	movb 0x7bff, %dl		# Drive (from Memory Loacation)
	int $0x13			# Disk Interrupt

	jc PrintErrorMsg		# If CF set jump to PrintErrorMsg

LoadFromDisk:
	movw $0x0050, %ax
	movw %ax, %es			# Set Extra Segment to 0x0050

	movb $0x02, %ah			# Read Disk Sectors
	movb $0x01, %al			# Read one sector only (512 bytes per sector)
	clrw %bx			# Offset 0 - Start of Segment
	clrb %ch			# Track 0
	movb $0x02, %cl			# Sector 2
	clrb %dh			#	Head 0
	movb 0x7bff, %dl		# Drive (from Memory Loacation)
	int $0x13			# Disk Interrupt

	jc PrintErrorMsg		# If CF set jump to PrintErrorMsg

SetupSegments:
	movw $0x0050, %ax		# Segment 0x0050
	movw %ax, %ds			# Set Data Segment
	movw %ax, %es			# Set Extra Segment
	movw %ax, %fs			# Set Data2 Segment
	movw %ax, %gs			# Set Data3 Segment
	movw %ax, %ss			# Set Stack Segment

	ljmp $0x0050, $0x0		# Far Jump to CS:IP

PrintErrorMsg:
	clrw %ax
	movw %ax, %es			# Set Extra Segment to 0x0
	movw $errmsg, %bp		# Set base pointer to msg location

	movb $0x13, %ah			# Print String
	movb $0x01, %al			# Char only - Cursor moved
	clrb %bh			# Page Number
	movb $0x04, %bl			# Color Black Red
	movw errmsglen, %cx		# Message Length
	movb $3, %dh			# Row 3
	movb $1, %dl			# Column 1
	int $0x10			# Print Message

	cli				# Disable Interrupts

Hang:
	hlt				# Halt CPU
	jmp Hang			# Infinit loop if Halt does not work
